Genotypes
=========

.. automodule:: anhima.gt
.. autofunction:: is_called
.. autofunction:: is_missing
.. autofunction:: is_hom
.. autofunction:: is_het
.. autofunction:: is_hom_ref
.. autofunction:: is_hom_alt
.. autofunction:: count_called
.. autofunction:: count_missing
.. autofunction:: count_hom
.. autofunction:: count_het
.. autofunction:: count_hom_ref
.. autofunction:: count_hom_alt
.. autofunction:: max_allele
.. autofunction:: as_haplotypes
.. autofunction:: as_n_alt
.. autofunction:: as_012
.. autofunction:: as_allele_counts
.. autofunction:: pack_diploid
.. autofunction:: unpack_diploid
.. autofunction:: count_genotypes
.. autofunction:: windowed_genotype_counts
.. autofunction:: windowed_genotype_density
.. autofunction:: windowed_genotype_rate
.. autofunction:: plot_windowed_genotype_counts
.. autofunction:: plot_windowed_genotype_density
.. autofunction:: plot_windowed_genotype_rate
.. autofunction:: plot_discrete_calldata
.. autofunction:: plot_continuous_calldata
.. autofunction:: plot_diploid_genotypes
.. autofunction:: plot_genotype_counts_by_sample
.. autofunction:: plot_genotype_counts_by_variant
.. autofunction:: plot_continuous_calldata_by_sample

